package com.fs.company.service;

import com.fs.company.domain.CompanyUser;
import com.fs.company.domain.CompanyWxAccount;

import java.util.List;

/**
 * 企微账号Service接口
 * 
 * @author fs
 * @date 2024-12-09
 */
public interface ICompanyWxAccountService 
{
    /**
     * 查询企微账号
     * 
     * @param id 企微账号ID
     * @return 企微账号
     */
    public CompanyWxAccount selectCompanyWxAccountById(Long id);

    /**
     * 查询企微账号列表
     * 
     * @param companyWxAccount 企微账号
     * @return 企微账号集合
     */
    public List<CompanyWxAccount> selectCompanyWxAccountList(CompanyWxAccount companyWxAccount);
    public List<CompanyWxAccount> selectCompanyWxAccountListCompany(CompanyWxAccount companyWxAccount);

    /**
     * 新增企微账号
     * 
     * @param companyWxAccount 企微账号
     * @return 结果
     */
    public int insertCompanyWxAccount(CompanyWxAccount companyWxAccount);

    /**
     * 修改企微账号
     * 
     * @param companyWxAccount 企微账号
     * @return 结果
     */
    public int updateCompanyWxAccount(CompanyWxAccount companyWxAccount);

    /**
     * 批量删除企微账号
     * 
     * @param ids 需要删除的企微账号ID
     * @return 结果
     */
    public int deleteCompanyWxAccountByIds(Long[] ids);

    /**
     * 删除企微账号信息
     * 
     * @param id 企微账号ID
     * @return 结果
     */
    public int deleteCompanyWxAccountById(Long id);

    List<CompanyUser> companyListAll();
    List<CompanyUser> companyListAllCompany(CompanyUser companyUser);

    CompanyWxAccount selectByCompanyUserAndWxNo(Long userId, String wxNo);
}
